#
# spec file for package udisks
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           udisks
Version:        1.0.2
Release:        3.6.1
License:        GPLv2+
Summary:        Disk Management Service
Url:            http://cgit.freedesktop.org/udisks/
Group:          System/Daemons
Source:         %{name}-%{version}.tar.bz2
# Need this one until bnc#504064 has been resolved -- mboman@suse.de
Source2:        umount.udisks
Obsoletes:      DeviceKit-disks <= 009
Provides:       DeviceKit-disks = 009
# avahi BuildRequires is solely for directory ownerships.
BuildRequires:  avahi
BuildRequires:  dbus-1-glib-devel
#BuildRequires:  device-mapper-devel
BuildRequires:  gtk-doc
BuildRequires:  intltool
BuildRequires:  libatasmart-devel
BuildRequires:  libgudev-1_0-devel
BuildRequires:  parted-devel
BuildRequires:  polkit-devel
BuildRequires:  sg3_utils-devel
#BuildRequires:  sqlite3-devel
# udev BuildRequires is solely for directory ownerships.
BuildRequires:  udev
#BuildRequires:  zlib-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Patch10:        udisks-kernel-module-load-fix.patch

%description
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

%package devel
License:        GPLv2+
Summary:        Disk Management Service - Development Files
Group:          Development/Libraries/Other
Requires:       %{name} = %{version}
Requires:       glib2-devel
Provides:       DeviceKit-disks-devel = 009
Obsoletes:      DeviceKit-disks-devel <= 009

%description devel
udisks provides a daemon, D-Bus API and command line tools
for managing disks and storage devices.

%prep
%setup -q
%patch10 -p1

%build
export V=1
%configure \
  --enable-gtk-doc \
  --disable-static \
  --libexecdir=%{_prefix}/lib/udisks
make %{?_smp_mflags}

%install
%makeinstall
find %{buildroot}%{_libdir} -name '*.la' -delete -print
# Not allowed to install into /sbin so move it to /usr/sbin (see bnc#504064)
mkdir -p %{buildroot}%{_sbindir}
mv %{buildroot}/sbin/umount.udisks %{buildroot}%{_sbindir}
cp %{S:2} %{buildroot}/sbin/
%find_lang %{name}

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files -f %{name}.lang
%defattr(-,root,root,-)
%doc AUTHORS COPYING NEWS README
/lib/udev/udisks-*
/lib/udev/rules.d/80-udisks.rules
%{_bindir}/udisks
%{_bindir}/udisks-tcp-bridge
%{_prefix}/lib/udisks
%{_libdir}/polkit-1/extensions/libudisks-action-*.so
%attr(0755,root,root) /sbin/umount.udisks
%{_sbindir}/umount.udisks
%{_datadir}/polkit-1/actions/*.policy
%{_datadir}/dbus-1/system-services/*.service
%{_sysconfdir}/dbus-1/system.d/*.conf
%attr(0644,root,root) %{_sysconfdir}/profile.d/udisks-bash-completion.sh
%{_sysconfdir}/avahi/services/udisks.service
%doc %{_mandir}/man?/*.*
%attr(0770,root,root) %dir %{_localstatedir}/lib/udisks

%files devel
%defattr(-,root,root,-)
%{_datadir}/pkgconfig/udisks.pc
%doc %{_datadir}/gtk-doc/html/udisks
%{_datadir}/dbus-1/interfaces/*.xml

%changelog
* Fri Jun 24 2011 kay.sievers@novell.com
- add missing comma to patch (bnc#691077)
* Tue Apr 26 2011 kay.sievers@novell.com
- Fix: Arbitrary LKMs from /lib/modules can be loaded
  CVE-2010-4661 (bnc#653900)
* Mon Dec 20 2010 vuntz@opensuse.org
- Update to version 1.0.2:
  + Add nilfs2 file system support
  + fdo#26258: initial btrfs support
  + Update to latest LVM2 API
  + Add udisks --eject option
  + Don't probe non-data discs for partition tables
  + Fix long hangs on probing nonexistant floppy drives
  + Fix hang on setting invalid VFAT labels
  + Fix mkfs.ext* arguments
  + Fix creating NTFS on raw devices
  + Also export UDISKS_DM_TARGET_PARAMS for 'multipath' target
  + Fix a bug of unquoted/unescaped label string
  + Escape backslash for label string
  + Escape NTFS labels properly
  + fdo#28075: Do not have all files executable on vfat
  + fdo#28075: Do not have files executable on NTFS
  + partutil: Explicitly use PART_TYPE_UNKNOWN
  + Fix building with Linux 2.6.37
  + fdo#30332: udisks does not tear down LUKS devices when the
    slave is forcibly removed
  + Avoid using entities in introspection XML
  + Various code fixes.
  + Improve testsuite.
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Thu Jul 15 2010 vuntz@opensuse.org
- Update umount.udisks script to reference /usr/sbin/umount.udisks
  instead of /usr/sbin/umount.devkit. Fix bnc#618955.
* Fri Apr  9 2010 kay.sievers@novell.com
- Update to version 1.0.1
  fix bug that publicly exports dm key information
  fdo#27494, CVE-2010-1149
* Thu Apr  1 2010 kay.sievers@novell.com
- install /var/lib/udisks -- needed for mtab mount tracking
  to be able to umount and cleanup /media directories
* Tue Mar  2 2010 dimstar@opensuse.org
- Provide / Obsolete DeviceKit-disks-devel.
* Thu Feb 25 2010 meissner@suse.de
- removed rpmlintrc, moved pkgconfig file to -devel
* Wed Feb 24 2010 dimstar@opensuse.org
- Rename package to udisks
- Update to git snapshot 7d998831 from 2010-02-24
* Fri Nov 13 2009 vuntz@opensuse.org
- Update to version 009:
  + Various device-mapper and cryptsetup fixes
  + Pass -T to cryptsetup to handle incorrect passphrases
  + When updating holders/slaves, defer the updates to an idle
    handler
  + Work around blkid incorrectly detecting FAT on extended
    partitions
  + Use 'udevadm settle' instead of 15-second timeout
  + Allow creating a partition table with same scheme as existing
    one
  + Pass -F to mkfs.ext[234] to allow creating a filesystem on the
    whole disk
  + Use unregister facility in dbus-glib 0.82 and misc life-cycle
    fixes
  + Add new LinuxMdComponentPosition property
  + Also ignore a device if DM_UDEV_DISABLE_OTHER_RULES_FLAG is set
  + Use BLKPG_DEL_PARTITION when deleting partitions instead of
    libparted
  + Use BLKPG_ADD_PARTITION when adding a partition
  + Don't use hyphens in param names
  + fdo#24673 - Support creating swap fs with labels
  + fdo#24778 - throw_error() segfaults for daemon-internally
    called methods
  + fdo#24757 - Bashism in luks helper breaks password changing
  + fdo#24757 - Simplify helper-change-luks-password
  + fdo#24679 - Support creating minix file systems
  + fdo#24718 - Proper handling of missing mkfs.*/fsck.*
- Changes from version 008:
  + Actually inhibit the daemon when Inhibit() is called
  + fdo#24054 - Devickit-disks doesn't support changing ntfs label
  + fdo#24343 - Unintended side-effect when calling DriveDetach()
  + fdo#24264 - Crash on removing NULL value from hash in
    device_remove()
  + fdo#24052 - CDROM eject button is locked while CDROM is mounted
  + fdo#24129 - Please mount vfat disks with shortname=mixed
  + fdo#24351 - Firewire hard drive is considered system-internal
  + fdo#24468 - part-id crashes if drive device node does not exist
  + fdo#24499 - media players have USB drive icon
  + fdo#24053 - MMC cards aren't automounted.
* Thu Oct  1 2009 vuntz@opensuse.org
- Update to version 007:
  + fdo#22914 – Require password to eject a CD or DVD mounted by
    the same user
  + Rework ATA SMART handling
  + Also be paranoid about the UUID containing '/' characters
  + Use WindowsStyleCaps for property names
  + fdo#23829 – Undefined value in partutil.c
  + fdo#23828 – Undefined value in umount-devkit.c
  + fdo#23827 – Undefined value
  + fdo#23826 – NULL dereference
  + fdo#23825 – Leak in update_info_mount_state
  + fdo#23824 – Unused variable
  + fdo#23823 – NULL dereference
  + fdo#23764 – Small leak in update_drive_properties_from_sysfs
  + fdo#23762 – Fix typo
  + fdo#23579 – Must allow DBus Properties interface for g-d-u to
    work
  + fdo#23926 – Error creating partition
  + fdo#23541 – PartitionTableCreate method times out
  + fdo#23761 – Some leaks
* Wed Sep  9 2009 vuntz@opensuse.org
- Update to version 006:
  + Add a way to spin down drives
  + Fix segfault when starting a Linux MD array
  + Fix polling process title and turn off noisy debugging spew
  + Pass size of buffer to avoid Z_BUF_ERROR when compressing ATA
    SMART blob
  + Add --poll-for-media option to devkit-disks(1)
  + Work around media detection problems
  + Move implementation of DrivePollMedia into a separate process
  + Move data files into a separate directory
  + Misc fixes for optical disc detection
  + Fix up ATA SMART detection
  + Add Device:drive-is-rotational property
  + Add LinuxMdCreate method
  + Rely on the disk to spin itself down
  + Require latest libatasmart
  + Fix up object path mapping
  + fdo#23309 – Udev rules probe floppy drives when they shouldn't
  + Add a new :device-presentation-nopolicy property
  + Ignore loop and ram devices for now
  + Make FilesystemMount() accept an 'auth_no_user_interaction'
    option
  + fdo#23235 – Cannot mount disc with / (slash) in label
  + Hide recovery, boot, and hidden partitions from desktops
* Wed Aug 26 2009 kay.sievers@novell.com
- get rid of obsolete DeviceKit-devel build dependency
* Tue Jul 21 2009 kay.sievers@novell.com
- update to version 005
  - use gudev instead of DeviceKit service
  - use polkit instead of PolicyKit
- do no use "lib64" directories for private directories
- silent overzealous rmplint:
    no, not all pkgconfig files do belong into -devel package
* Sun Jul 12 2009 coolo@novell.com
- buildrequire udev to fix file lists
* Sun May 10 2009 mboman@suse.de
- First checkin
- Add a bash script, umount.devkit, to be installed into /sbin,
  bnc#504064
